@@ -4,10 +4,10 @@ import subprocess
 from functools import partial
 from typing import Sequence
 
-from ..config import Config
-from ..core.api import FormatCode
-from ..utils.logger import getLogger
-from ..utils.io import StdinResource, FileResource, _ResourceBase
+from lambdex.fmt.jobs_meta import JobsMeta
+from lambdex.fmt.core.api import FormatCode
+from lambdex.fmt.utils.logger import getLogger
+from lambdex.fmt.utils.io import StdinResource, FileResource, _ResourceBase
 
 logger = getLogger(__name__)
 
@@ -26,21 +26,30 @@ class BaseAdapter(abc.ABC):
         self.opts = opts
         self.backend_argv = backend_argv
 
-        self.config = self._make_config()
+        self.jobs_meta = self._make_jobs_meta()
 
     @abc.abstractmethod
-    def _make_config(self) -> Config:
+    def _make_jobs_meta(self) -> JobsMeta:
         pass
 
     @abc.abstractmethod
     def _get_backend_cmd_for_resource(self, resource: _ResourceBase) -> Sequence[str]:
         pass
 
-    def _job(self, filename=None) -> bool:
+    def _reset_aliases(self, filename):
+        from lambdex.fmt.core.tkutils.rules import matcher
+
         if filename is None:
-            resource = StdinResource(self.config)
+            matcher.reset_aliases()
         else:
-            resource = FileResource(self.config, filename)
+            matcher.reset_aliases(filename)
+
+    def _job(self, filename=None) -> bool:
+        self._reset_aliases(filename)
+        if filename is None:
+            resource = StdinResource(self.jobs_meta)
+        else:
+            resource = FileResource(self.jobs_meta, filename)
 
         cmd = self._get_backend_cmd_for_resource(resource)
         backend_result = self.call_backend(cmd, resource.source)
@@ -54,10 +63,10 @@ class BaseAdapter(abc.ABC):
         return resource.is_changed(formatted_code)
 
     def get_jobs(self):
-        if not self.config.files:
+        if not self.jobs_meta.files:
             yield self._job
         else:
-            yield from (partial(self._job, filename) for filename in self.config.files)
+            yield from (partial(self._job, filename) for filename in self.jobs_meta.files)
 
     def call_backend(self, cmd: Sequence[str], stdin: bytes) -> Result:
         process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stdin=subprocess.PIPE)
