@@ -5,6 +5,35 @@ from lambdex.fmt.core.definitions import State, Context, TokenInfo, tk, A, actio
 from .matcher import matcher as m
 
 
+@m(exact_type=tk.NEWLINE, last_state=State.EXPECT_LBDX_LPAR)
+@m(exact_type=tk.NEWLINE, last_state=State.MUST_LBDX_LPAR)
+@m(exact_type=tk.NEWLINE, last_state=State.EXPECT_LBDX_NAME)
+def r(ctx: Context, token: TokenInfo):
+    ctx.pop_state()
+    return actions.StopBuffer()
+
+
+@m(exact_type=tk.COMMENT, last_state=State.DISABLED)
+@m(exact_type=tk.COMMENT, last_state=State.UNKNOWN)
+def r(ctx: Context, token: TokenInfo):
+    directive = token.lxfmt_directive()
+    if directive == 'off' and ctx.last_state != State.DISABLED:
+        ctx.push_state(State.DISABLED)
+
+    elif directive == 'on' and ctx.last_state == State.DISABLED:
+        ctx.pop_state()
+
+
+@m(exact_type=tk.NL, last_state='ALL')
+@m(exact_type=tk.NEWLINE, last_state='ALL')
+@m(exact_type=tk.WHITESPACE, last_state='ALL')
+@m(exact_type=tk.COMMENT, last_state='ALL')
+@m(exact_type=tk.TYPE_IGNORE, last_state='ALL')
+@m(exact_type=tk.TYPE_COMMENT, last_state='ALL')
+def r(ctx: Context, token: TokenInfo):
+    return
+
+
 @m(exact_type=tk.LPAR)
 @m(exact_type=tk.LSQB)
 @m(exact_type=tk.LBRACE)
@@ -26,6 +55,11 @@ def r(ctx: Context, token: TokenInfo):
 @m(exact_type=tk.NAME, string=_Aliases.def_, last_state=State.IN_LBDX_CLS_HEAD)
 @m(exact_type=tk.NAME, string=_Aliases.def_, last_state=State.IN_LBDX_CLS_BODY)
 @m(exact_type=tk.NAME, string=_Aliases.def_, last_state=State.IN_LBDX_BODY_LIST)
+@m(exact_type=tk.NAME, string=_Aliases.async_def_, last_state=State.UNKNOWN)
+@m(exact_type=tk.NAME, string=_Aliases.async_def_, last_state=State.IN_LBDX_LAMBDA)
+@m(exact_type=tk.NAME, string=_Aliases.async_def_, last_state=State.IN_LBDX_CLS_HEAD)
+@m(exact_type=tk.NAME, string=_Aliases.async_def_, last_state=State.IN_LBDX_CLS_BODY)
+@m(exact_type=tk.NAME, string=_Aliases.async_def_, last_state=State.IN_LBDX_BODY_LIST)
 def r(ctx: Context, token: TokenInfo):
     ctx.push_state(State.EXPECT_LBDX_LPAR)
 
@@ -73,6 +107,8 @@ def r(ctx: Context, token: TokenInfo):
 
 @m(exact_type=tk.COLON, last_state=State.IN_LBDX_LAMBDA)
 def r(ctx: Context, token: TokenInfo):
+    if ctx.last_op[1] != State.IN_LBDX_CALL:
+        return
     ctx.pop_state()
     ctx.push_state(State.EXPECT_LBDX_LSQB)
 
@@ -144,11 +180,15 @@ def r(ctx: Context, token: TokenInfo):
 
 @m(exact_type=tk.NAME, string=_Aliases.if_, last_state=State.IN_LBDX_BODY_LIST)
 @m(exact_type=tk.NAME, string=_Aliases.with_, last_state=State.IN_LBDX_BODY_LIST)
+@m(exact_type=tk.NAME, string=_Aliases.async_with_, last_state=State.IN_LBDX_BODY_LIST)
 @m(exact_type=tk.NAME, string=_Aliases.for_, last_state=State.IN_LBDX_BODY_LIST)
+@m(exact_type=tk.NAME, string=_Aliases.async_for_, last_state=State.IN_LBDX_BODY_LIST)
 @m(exact_type=tk.NAME, string=_Aliases.while_, last_state=State.IN_LBDX_BODY_LIST)
 @m(exact_type=tk.NAME, string=_Aliases.if_, last_state=State.IN_LBDX_CLS_BODY)
 @m(exact_type=tk.NAME, string=_Aliases.with_, last_state=State.IN_LBDX_CLS_BODY)
+@m(exact_type=tk.NAME, string=_Aliases.async_with_, last_state=State.IN_LBDX_CLS_BODY)
 @m(exact_type=tk.NAME, string=_Aliases.for_, last_state=State.IN_LBDX_CLS_BODY)
+@m(exact_type=tk.NAME, string=_Aliases.async_for_, last_state=State.IN_LBDX_CLS_BODY)
 @m(exact_type=tk.NAME, string=_Aliases.while_, last_state=State.IN_LBDX_CLS_BODY)
 def r(ctx: Context, token: TokenInfo):
     ctx.push_state(State.EXPECT_CLS_HEAD_LSQB)
