@@ -5,7 +5,7 @@ colorful = os.getenv('NOCOLOR') is None
 if colorful:
     try:
         from termcolor import colored
-    except ModuleNotFoundError:
+    except ImportError:
         colorful = False
 
 if not colorful:
