@@ -1,8 +1,8 @@
 from .utils.repl_compat import patch
 
 # Export all keywords
-from .keywords import *
-from .keywords import __all__
+from ._exports import *
+from ._exports import __all__
 
 # Patch the current REPL environment
 patch()
\ No newline at end of file
